
#*********Load Client dll**********
load "mapsclientifc.dll"

#*******************Array of Ports\Devices***********************
set list1 { 1 2 3 4 5 6 7 8 }
set deviceList { 1 2 }

#***********************Test Done*********************************
set testDone(1) 0
set testDone(2) 0
set testDone(3) 0
set testDone(4) 0
set testDone(5) 0
set testDone(6) 0
set testDone(7) 0
set testDone(8) 0
set testDone(9) 0
set testDone(10) 0
set testDone(11) 0
set testDone(12) 0
set testDone(13) 0
set testDone(14) 0
set testDone(15) 0
set testDone(16) 0
#*********************** Test Stop Method ********************
set autoStop 1
#***************Test Duration************************
set testDuration 10000
#***************Polling Interval - rate at which stats are spit to the tcl client during operation***********************
set pollingInterval 2000

#************Periodicity (in minutes)*********************
set enablePeriodicReporting 1
set filePath {"C:"}
set periodicity 1

#***********Config Method****************
set loadFromXML 1

#***********Profile names****************
set xmlProfile {"PEX_BERT_Profile.xml"}
set xmlIfcCfgProfile {"PEX_Interface_Profile.xml"}

#*******************
#*** MAIN SCRIPT ***
#*******************

#***Server ID\Script Ids are declared here********
source Global_Vars.tcl

#Assign PEX MAPS CLI Server Id
global CLIPEXID

#Assign Ids for Initialisation script and BERT Script
global InitScriptId 
global BERTScriptId 

#Assign variable to hold the Number of PacketExpert Devices found
global DeviceCount

#Load TCL Procedure files
source Procs_LoadModule.tcl
source Procs_BERT.tcl
source Procs_BERT_StartStop.tcl
source Procs_PortStats_BERTResults.tcl
source Procs_Load_Apply_Cfg.tcl

#***********Initialise PEX MAPS CLI Server and PacketExpert ***************#
source PEX_Init.tcl
#**************************************************************************#

#***********Load BERT module on all devices ***************#
InitApp $DeviceCount "AllPortBert"

#************************************************Start BERT application**************************************************************
maps Cmd $CLIPEXID StartScript $BERTScriptId {"PEX_BERT_Main.gls" "" 1}

#Initialise BERT
maps Cmd $CLIPEXID UserEvent $BERTScriptId {"InitBertModule"} #BoardCount = $DeviceCount
after 2000
waitforevent $CLIPEXID $BERTScriptId BERTInit 100 sec
puts $BERTInit

puts "Loading bert profile"

#*** Config File *** 
foreach port_index $list1 {
	if { $loadFromXML == 1 } {
		#Tx Config
		set txSubProfile [ format "Port%dTxConfig" $port_index ]
		LoadBertProfiles $BERTScriptId $xmlProfile $txSubProfile
		#Rx Config
		set rxSubProfile [ format "Port%dRxConfig" $port_index ]
		LoadBertProfiles $BERTScriptId $xmlProfile $rxSubProfile
		
		#Interface Config
		set ifcSubProfile [ format "Port%dInterfaceConfig" $port_index]
		LoadInterfaceProfiles $BERTScriptId $xmlIfcCfgProfile $ifcSubProfile
	} else {
	set scriptFile [ concat "Set_BERTParameters_Port$port_index.tcl" ]
	source $scriptFile
	}
	maps Cmd $CLIPEXID UserEvent $BERTScriptId {"ApplyConfiguration"} # PortIndex = $port_index
	waitforevent $CLIPEXID $BERTScriptId PortConfigStatus 100 sec
}

#Set periodicity
if { $enablePeriodicReporting == 1 } {
	maps Cmd $CLIPEXID UserEvent $BERTScriptId {"SetPeriodicity"} # Periodicity = $periodicity
	# Start periodic reporting to csv
	foreach port_index $list1 {
		maps Cmd $CLIPEXID UserEvent $BERTScriptId {"EnablePeriodicCsvReport"} # PortIndex = $port_index , FilePath = $filePath
		waitforevent $CLIPEXID $BERTScriptId EnablePeriodicity 10 sec
		puts $EnablePeriodicity
	}
}

#Set Test duration
if { $autoStop == 1 } {
	foreach port_index $list1 {
		maps Cmd $CLIPEXID UserEvent $BERTScriptId {"SetTestDuration"} # PortIndex = $port_index , TestDuration = $testDuration
	}
}

# Start BERT
foreach port_index $list1 {
	StartBERT $BERTScriptId $port_index
}
 
#**********************************************************Statistics\Results******************************************************
if { $autoStop == 1 } {
	#Auto stop
	while {1} {
		foreach port_index $list1 {
			maps Cmd $CLIPEXID UserEvent $BERTScriptId {"IsPortRunning"} # PortIndex = $port_index
			waitforevent $CLIPEXID $BERTScriptId IsRunning 2 sec
			if { $IsRunning == 0 } { set testDone($port_index) 1
			} else { puts ""
				puts "Bert $port_index results"
				GetBERTResults $BERTScriptId $port_index
				#GetTxStatistics $BERTScriptId $port_index
				#GetRxStatistics $BERTScriptId $port_index
			}
		}
		
		set allTestDone 1
		foreach port_index $list1 {
			if { $testDone($port_index) == 1 && $allTestDone ==1 } { set allTestDone 1
			} else { set allTestDone 0
			}
		}
		if { $allTestDone == 1 } { 
			#Print final results and exit the loop
			foreach port_index $list1 {
				puts ""
				puts "Bert $port_index results"
				GetBERTResults $BERTScriptId $port_index
			}
		break
		}
		after $pollingInterval
	}
} else {
	#Manual stop 
	set pollCount [expr {$testDuration/$pollingInterval}]
	set counter 0

	while {$counter < $pollCount} { 
		foreach port_index $list1 {
			puts ""
			puts "Bert Port$port_index results"
			GetBERTResults $BERTScriptId $port_index
		}
		incr counter
		after $pollingInterval
	}
	
	# Stop BERT
	foreach port_index $list1 {
		StopBERT $BERTScriptId $port_index
	}
}
	


#Stop periodic reporting
foreach port_index $list1 {
	maps Cmd $CLIPEXID UserEvent $BERTScriptId {"StopPeriodicCsvReport"} # PortIndex = $port_index
}

maps Cmd $CLIPEXID UserEvent $BERTScriptId {"GenerateReport"} # ReportTitle = {"PacketExpert"} , ReportComments = {"BertReport"} , ReportHeader = {"GLCommunications"} , ReportFooter = {"BERT"} , ReportLogo = {"GL_Logo.jpg"} , ReportFileName = {"Test.pdf"} 

after 5000

maps cmd $CLIPEXID StopScript $BERTScriptId

